"""Module containing functionality to interact with the filesystem"""

import os

from maildirclean.maildir import MailDir, TopSender


def delete_all_from_selected_email(
    selected_senders: list[TopSender], maildir: MailDir, confirm=True
):
    for sender in selected_senders:
        emails = maildir.get_paths_for_email(sender.email)
        if confirm:
            print(
                f"Deleting {len(emails)} addressed from sender {sender.email}\nConfirm (y)"
            )
            if input("> ").strip() not in ["y", "Y", "yes", "Yes"]:
                print(f"Cancelling delete")
                continue
        delete_files(emails)
        maildir.remove_email(sender.email)


def delete_files(file_list: list[str]):
    """Delete all files in the provided file list

    Args:
        file_list: List of file paths as either strings or Path
    """
    for file in file_list:
        os.remove(file)
